%% profile_ex3.m -- an executable m-file for solving a partial differential equation
% Automatically created in CHEBGUI by user takitoshi.
% Created on February 24, 2018 at 11:59.

%% Problem description.
% Solving
%   u_t = -(-1+0.3*sin(3*x)-0.19*cos(2*x))*u',
% for x in [0,6.2832] and t in [0,10], subject to periodic boundary conditions.

%% Problem set-up
% Create an interval of the space domain...
dom = [0 2*pi];
%...and specify a sampling of the time domain:
t = 0:.1:10;

% Make the right-hand side of the PDE.
pdefun = @(t,x,u) -(-1+0.3.*sin(3.*x)-0.19.*cos(2.*x)).*diff(u);

% Assign boundary conditions.
bc = 'periodic';

% Construct a chebfun of the space variable on the domain,
x = chebfun(@(x) x, dom);
% and of the initial condition.
u0 = 3./(5+4.*cos(x));

%% Setup preferences for solving the problem.
opts = pdeset('Eps', 1e-6, 'Ylim', [0,3]);

%% Call pde23t to solve the problem.
[t, u] = pde23t(pdefun, t, u0, bc, opts);

%% Plot the solution.
% LW = 'linewidth';lw = 0.8;
waterfall(u,t)
view(10,70)
colormap([0,0,0])
axis([0,2*pi,0,10,0,3])
xlabel('$x$','interpreter','latex')
ylabel('$t$','interpreter','latex')
zlabel('$\tilde{u}(x,t)$','interpreter','latex')
grid off